@@ -226,7 +226,7 @@ def list_queries(ctx, user_name, status, num, is_raw):
     List the queries that have been run by this user
     """
     svc = ctx.obj.service
-    queries = svc.get_queries(limit=num)
+    queries = svc.get_queries(limit=num, user_name=user_name)
     if is_raw:
         click.echo(dumps([q.raw for q in queries]))
         return
