@@ -16,7 +16,11 @@ log = get_logger()
 @option('--mine', 'is_mine', is_flag=True, help='List jobs from me')
 @option('-u', '--user', 'user_name', help='User to filter for')
 @option('-s', '--status', 'status', default=None, help='Filter status')
-@option('-p', '--page', 'is_page', is_flag=True, help='Page results')
+@option('-p', '--project', 'project', default=None, help='Filter by project name')
+@option('--pipeline', 'pipeline', default=None, help='Filter by pipeline name')
+@option('--page', 'is_page', is_flag=True, help='Page results')
+@option('--running', 'is_running', is_flag=True, help='Only show jobs in pending/running state')
+@option('--finished', 'is_finished', is_flag=True, help='Only show jobs in failed/cancelled/finished state')
 @option('-n', '--num', default=20, help='Maximum number of jobs to return')
 @option(
     '-o',
@@ -27,13 +31,21 @@ log = get_logger()
 )
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json for further processing')
 @pass_context
-def jobs(ctx, is_mine, user_name, status, is_page, num, output, is_raw):
+def jobs(ctx, is_mine, user_name, status, project, pipeline, is_page, is_running, is_finished, num, output, is_raw):
     svc = ctx.obj.service
     if is_mine:
-        user_name = svc.current_user['email']
+        try:
+            user_name = svc.current_user['email']
+        except KeyError:
+            abort("You appear not to be logged in")
 
+    state = None
+    if is_running:
+        state = "running"
+    elif is_finished:
+        state = "finished"
     try:
-        jobs = svc.get_jobs(user_name, status, num)
+        jobs = svc.get_jobs(user_name, status, project=project, pipeline=pipeline, limit=num, state=state)
     except ServerError as e:
         abort(str(e))
     is_wide = output == 'wide'
@@ -51,7 +63,7 @@ def jobs(ctx, is_mine, user_name, status, is_page, num, output, is_raw):
         'status',
     ]
     if is_wide:
-        fields.extend(['complete_date', 'pod', 'processes'])
+        fields.extend(['desc', 'complete_date', 'pod', '#proc'])
     jobs_list = []
     for job in jobs:
         job_list = []
@@ -69,8 +81,10 @@ def jobs(ctx, is_mine, user_name, status, is_page, num, output, is_raw):
                 v = click.style(v, fg=col, bold=True)
             elif f == 'pod':
                 v = job.details.get('pod_name', v)
-            elif f == 'processes':
+            elif f == '#proc':
                 v = sum(job.details.get('process_stats', {}).values())
+            elif f == 'desc':
+                v = job.description
             job_list.append(v)
 
         jobs_list.append(job_list)
