@@ -19,7 +19,7 @@ log = logging.getLogger(__name__)
 @argument('pipeline_name', required=False)
 @argument('project_name', required=False)
 @option('-p', '--parameters', help="Parameters for the run", multiple=True)
-@option('-s', '--script', help="Bitbucket link to a workflow (only for custom)")
+@option('-s', '--script', help="Git link to a workflow (only for custom)")
 @option('-r', '--revision', help="Git SHA to run")
 @option('--profile', help="Nextflow configuration profile to use")
 @option('--local', 'local_folder', help='Run a local nextflow folder')
